@@ -11,10 +11,10 @@ requirements = {
 }
 [require(i) for i in requirements]
 
-from . import matchers as _
+from . import matchers as matchers
 from .config import Config
 
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 __plugin_meta__ = PluginMetadata(
     name="exe_code",
     description="在对话中执行 Python 代码",
