@@ -3,7 +3,7 @@ import contextlib
 import functools
 import uuid
 from datetime import timedelta
-from typing import Any, Optional, override, Protocol, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Protocol, override
 
 from nonebot import on_fullmatch, on_message
 from nonebot.log import logger
@@ -86,7 +86,7 @@ with contextlib.suppress(ImportError):
                 on_message(rule, handlers=[handle_ob], temp=True, expire_time=expire),
             }
 
-            def cleanup():
+            def cleanup() -> None:
                 for matcher in matchers:
                     with contextlib.suppress(ValueError):
                         matcher.destroy()
@@ -116,7 +116,7 @@ with contextlib.suppress(ImportError):
             self,
             api: str,
             *,
-            raise_text: Optional[str] = None,
+            raise_text: str | None = None,
             **data: Any,
         ) -> Result:
             res: dict[str, Any] | list[Any] | None = None
@@ -151,6 +151,7 @@ with contextlib.suppress(ImportError):
         )
         @debug_log
         async def recall(self, msg_id: int) -> Result:
+            logger.debug(f"[OneBot V11] 撤回消息: {msg_id=}")
             return await self.call_api(
                 "delete_msg",
                 message_id=msg_id,
@@ -165,6 +166,7 @@ with contextlib.suppress(ImportError):
         )
         @debug_log
         async def get_msg(self, msg_id: int) -> Message:
+            logger.debug(f"[OneBot V11] 获取消息: {msg_id=}")
             res = await self.call_api(
                 "get_msg",
                 message_id=msg_id,
@@ -180,6 +182,7 @@ with contextlib.suppress(ImportError):
         )
         @debug_log
         async def get_fwd(self, msg_id: int) -> list[Message]:
+            logger.debug(f"[OneBot V11] 获取合并转发消息: {msg_id=}")
             res = await self.call_api(
                 "get_forward_msg",
                 message_id=msg_id,
@@ -195,7 +198,7 @@ with contextlib.suppress(ImportError):
             ),
         )
         @debug_log
-        async def img_summary(self, summary: str, url: Optional[str] = None) -> None:
+        async def img_summary(self, summary: str, url: str | None = None) -> None:
             if url is None:
                 from ...context import Context
 
@@ -204,16 +207,18 @@ with contextlib.suppress(ImportError):
             if not url:
                 raise ValueError("无效 url")
 
+            logger.debug(f"[NapCat] 创建图片外显: <y>{summary}</y>, <c>{url}</c>")
             seg = MessageSegment.image(url)
             seg.data["summary"] = summary
             await self._native_send(Message(seg))
 
         @override
         def export_to(self, context: T_Context) -> None:
-            super(API, self).export_to(context)
+            super().export_to(context)
             context["Message"] = Message
             context["MessageSegment"] = MessageSegment
 
         @override
-        async def _send_ark(self, ark: "MessageArk") -> None:
-            await self._native_send(await create_ark_card(self, ark))
+        async def _send_ark(self, ark: "MessageArk") -> Any:
+            card = Message(await create_ark_card(self, ark))
+            return await self._native_send(card)
