@@ -1,6 +1,7 @@
 import asyncio
 import json
-from typing import Any, Awaitable, ClassVar, Optional, cast, override
+from collections.abc import Awaitable
+from typing import Any, ClassVar, override
 
 from nonebot.adapters import Adapter, Bot, Event, Message, MessageSegment
 from nonebot.internal.matcher import current_event
@@ -59,19 +60,17 @@ class API(Interface):
     gid: str | None
     session: Session
     event: Event
-    __is_super_user: bool
 
     def __init__(self, bot: Bot, session: Session) -> None:
-        super(API, self).__init__()
+        super().__init__()
         self.bot = bot
         self.qid = session.id1 or ""
         self.gid = session.id2
         self.session = session
         self.event = current_event.get()
-        self.__is_super_user = is_super_user(self.bot, self.qid)
 
-    async def _native_send(self, msg: str | Message | MessageSegment) -> None:
-        await self.bot.send(self.event, msg)
+    async def _native_send(self, msg: str | Message | MessageSegment) -> Any:
+        return await self.bot.send(self.event, msg)
 
     @descript(
         description="向QQ号为qid的用户发送私聊消息",
@@ -228,9 +227,11 @@ class API(Interface):
         self,
         prompt: T_Message = "",
         timeout: float = 30,
-    ) -> Optional[Message]:
+    ) -> UniMessage:
         prompt = await (await as_unimsg(prompt)).export() if prompt else ""
-        return await waiter_prompt(prompt, timeout=timeout)
+        if result := await waiter_prompt(prompt, timeout=timeout):
+            return await UniMessage.generate(message=result)
+        raise TimeoutError("input 超时")
 
     @export
     @descript(
@@ -240,9 +241,9 @@ class API(Interface):
     @debug_log
     def help(self, method: Any = ...) -> Awaitable[Receipt]:
         if method is not ...:
-            desc = cast(FuncDescription, getattr(method, INTERFACE_METHOD_DESCRIPTION))
+            desc: FuncDescription = getattr(method, INTERFACE_METHOD_DESCRIPTION)
             text = desc.format(method)
-            if is_export_method(method):
+            if not is_export_method(method):
                 text = f"{self.__inst_name__}.{text}"
             return self.feedback(text)
 
@@ -279,15 +280,13 @@ class API(Interface):
 
     @override
     def export_to(self, context: T_Context) -> None:
-        super(API, self).export_to(context)
+        super().export_to(context)
 
         context.update(load_const(self.qid))
         context["qid"] = self.qid
         context["gid"] = self.gid
-        # context["usr"] = self.user(self.qid)
-        # context["grp"] = self.group(self.gid) if self.gid else None
 
-        if self.__is_super_user:
+        if is_super_user(self.bot, self.qid):
             export_manager(context)
 
     def __repr__(self) -> str:
