@@ -1,4 +1,5 @@
-from typing import TYPE_CHECKING, Awaitable, ClassVar
+from collections.abc import Awaitable
+from typing import TYPE_CHECKING, ClassVar
 
 from nonebot_plugin_alconna.uniseg import Receipt
 
@@ -16,8 +17,8 @@ class Group(Interface):
     api: "API"
     uid: str
 
-    def __init__(self, api: "API", uid: str):
-        super(Group, self).__init__()
+    def __init__(self, api: "API", uid: str) -> None:
+        super().__init__()
         self.api = api
         self.uid = uid
 
