@@ -1,10 +1,10 @@
 import inspect
-from collections.abc import Awaitable
+from collections.abc import Awaitable, Callable
 from dataclasses import dataclass
-from typing import Any, Callable, Optional
+from types import UnionType
+from typing import Any
 
 from nonebot.adapters import Message, MessageSegment
-from nonebot.typing import type_has_args
 from nonebot_plugin_alconna.uniseg import Receipt
 
 from ..constant import (
@@ -21,7 +21,7 @@ from .utils import Result
 EMPTY = inspect.Signature.empty
 
 
-type_alias: dict[type, str] = {
+type_alias: dict[type | UnionType, str] = {
     Receipt: "Receipt",
     Result: "Result",
     T_Message: "T_Message",
@@ -59,8 +59,8 @@ def func_declaration(func: Callable[..., Any], ignore: set[str]) -> str:
 @dataclass
 class FuncDescription:
     description: str
-    parameters: Optional[dict[str, str]]
-    result: Optional[str]
+    parameters: dict[str, str] | None
+    result: str | None
     ignore: set[str]
 
     def format(self, func: Callable[..., Any]):
@@ -79,10 +79,10 @@ class FuncDescription:
 # fmt: off
 def descript[**P, R](
     description: str,
-    parameters: Optional[dict[str, str]],
-    result: Optional[str] = None,
+    parameters: dict[str, str] | None,
+    result: str | None = None,
     *,
-    ignore: Optional[set[str]] = None,
+    ignore: set[str] | None = None,
 ) -> Callable[[Callable[P, R]], Callable[P, R]]:
     # fmt: on
     ignore = {"self", *(ignore or set())}
@@ -95,7 +95,7 @@ def descript[**P, R](
             for name, param in sig.parameters.items():
                 if name == "self" or name in ignore:
                     continue
-                text = f"方法 '{call.__name__}' 的参数 '{name}'"
+                text = f"方法 {call.__name__!r} 的参数 {name!r}"
                 assert param.annotation is not EMPTY, f"{text} 未添加类型注释"
                 assert name in parameters, f"{text} 未添加描述"
 
@@ -105,7 +105,8 @@ def descript[**P, R](
             if origin is Awaitable:
                 ret = args[0]
 
-        assert ret is not EMPTY, f"方法 '{call.__name__}' 的返回值未添加类型注释"
+        text = f"方法 {call.__name__!r} 的返回值"
+        assert ret is not EMPTY, f"{text} 未添加类型注释"
 
         if result is None:
             if ret is Result:
@@ -113,7 +114,7 @@ def descript[**P, R](
             elif ret is Receipt:
                 result = DESCRIPTION_RECEIPT_TYPE
             elif "return" not in ignore:
-                assert ret is None, f"方法 '{call.__name__}' 的返回值未添加描述"
+                assert ret is None, f"{text} 未添加描述"
 
         setattr(
             call,
